@@ -70,12 +70,10 @@ int main(int argc, char **argv)
     signal(SIGINT, sigterm_handler);
     signal(SIGHUP, sigterm_handler);
 
-    KAboutData::setApplicationData(aboutData());
     QApplication::setDesktopSettingsAware(false);
     QApplication a(argc, argv);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+    KAboutData::setApplicationData(aboutData());
     QGuiApplication::setFallbackSessionManagementEnabled(false);
-#endif
     auto disableSessionManagement = [](QSessionManager &sm) {
             sm.setRestartHint(QSessionManager::RestartNever);
     };
@@ -157,7 +155,7 @@ void KWrited::block_in()
   msg.remove('\r');
   msg.remove('\a');
 
-  KNotification *notification = new KNotification("NewMessage", 0, KNotification::Persistent);
+  KNotification *notification = new KNotification("NewMessage", nullptr, KNotification::Persistent);
 #if !defined(BUILD_AS_EXECUTABLE)
   notification->setComponentName( QStringLiteral("kwrited") );
 #endif
